@@ -1,10 +1,11 @@
-package Firewall::Connector::Role;
+package Netstack::Connector::Role;
 
 #------------------------------------------------------------------------------
 # 加载扩展模块
 #------------------------------------------------------------------------------
 use 5.016;
 use utf8;
+use Encode;
 use Try::Tiny;
 use Expect;
 use Moose::Role;
@@ -367,7 +368,7 @@ sub getConfig {
 
   # 抓取设备命令脚本，输入不分页命令加速输出
   my $commands = $self->getCommands;
-  my $ret      = $self->execCommands( $commands->@* );
+  my $ret      = decode_utf8 $self->execCommands( $commands->@* );
 
   # 判断是否执行成功
   if ( $ret->{success} == 1 ) {
@@ -416,6 +417,7 @@ sub execCommands {
 
   # 初始化 result 变量，并开始执行命令
   my $result = "";
+
   # 初始化 commands 属性
   $self->setCommands( \@commands );
   # 遍历接受到的命令行
@@ -439,8 +441,13 @@ sub execCommands {
     }
     # 脚本执行正常,则拼接字符串
     $result .= $buff;
+    $result =~ s/\r\n/\n/g;
+    $result =~ s/\015//g;
   }
 
+  # 将字串转换为 utf8
+  $result = decode_utf8 $result;
+
   # 输出计算结果
   return {
     success => 1,
